@@ -4,7 +4,7 @@ import typing
 import numpy as np
 from PySide2.QtCore import Signal, QThread, QSize, Slot
 from PySide2.QtGui import QResizeEvent
-from PySide2.QtWidgets import QGraphicsScene, QGraphicsSimpleTextItem, QGraphicsView, QSizePolicy
+from PySide2.QtWidgets import QGraphicsSimpleTextItem, QSizePolicy, QWidget
 
 from zero_play.game_state import GameState
 from zero_play.log_display import LogDisplay
@@ -12,7 +12,7 @@ from zero_play.mcts_player import MctsPlayer
 from zero_play.mcts_worker import MctsWorker
 
 
-class GameDisplay(QGraphicsView):
+class GameDisplay(QWidget):
     default_font = 'Sans Serif,9,-1,5,50,0,0,0,0,0'
     rules_path: typing.Optional[str] = None
 
@@ -21,7 +21,7 @@ class GameDisplay(QGraphicsView):
     game_ended = Signal(np.ndarray)  # final_board
 
     def __init__(self, start_state: GameState):
-        super().__init__(scene=QGraphicsScene())
+        super().__init__()
         self.start_state = start_state
         self.mcts_workers: typing.Dict[int, MctsWorker] = {}
         self.worker_thread: typing.Optional[QThread] = None
@@ -30,6 +30,7 @@ class GameDisplay(QGraphicsView):
         self._show_coordinates = False
         self.log_display = LogDisplay()
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+        self.is_reviewing = False
 
     @property
     def show_coordinates(self):
@@ -48,8 +49,7 @@ class GameDisplay(QGraphicsView):
 
     @mcts_players.setter
     def mcts_players(self, players: typing.Sequence[MctsPlayer]):
-        if self.worker_thread is not None:
-            self.worker_thread.quit()
+        self.stop_workers()
 
         self.log_display = LogDisplay()
         self.mcts_workers = {player.player_number: MctsWorker(player)
@@ -78,8 +78,6 @@ class GameDisplay(QGraphicsView):
         """
 
     def resizeEvent(self, event: QResizeEvent):
-        view_size = event.size()
-        self.scene().setSceneRect(0, 0, view_size.width(), view_size.height())
         self.update_board(self.current_state)
 
     @property
@@ -97,15 +95,15 @@ class GameDisplay(QGraphicsView):
         return 'to move'
 
     @Slot(int)  # type: ignore
-    def make_move(self, move):
+    def make_move(self, move: int):
         self.log_display.record_move(self.current_state, move)
         # noinspection PyUnresolvedReferences
-        self.move_made.emit(self.current_state)
+        self.move_made.emit(self.current_state)  # type: ignore
         self.current_state = self.current_state.make_move(move)
         self.update_board(self.current_state)
         if self.current_state.is_ended():
             # noinspection PyUnresolvedReferences
-            self.game_ended.emit(self.current_state)
+            self.game_ended.emit(self.current_state)  # type: ignore
 
         forced_move = self.get_forced_move()
         if forced_move is None:
@@ -121,10 +119,10 @@ class GameDisplay(QGraphicsView):
         """
         return None
 
-    @Slot(np.ndarray, int, list)  # type: ignore
+    @Slot(GameState, int, list)  # type: ignore
     def analyse_move(
             self,
-            board: np.ndarray,
+            board: GameState,
             analysing_player: int,
             move_probabilities: typing.List[typing.Tuple[str,
                                                          float,
@@ -142,12 +140,20 @@ class GameDisplay(QGraphicsView):
         self.move_needed.emit(player, self.current_state)
 
     def close(self):
+        self.stop_workers()
+
+    def stop_workers(self):
         if self.worker_thread is not None:
             self.worker_thread.quit()
 
+    def can_move(self):
+        if self.is_reviewing:
+            return False
+        return not self.current_state.get_active_player() in self.mcts_workers
+
 
 def center_text_item(item: QGraphicsSimpleTextItem, x: float, y: float):
     bounds = item.boundingRect()
-    x -= bounds.width() / 2
-    y -= bounds.height() / 2
+    x -= bounds.width() // 2
+    y -= bounds.height() // 2
     item.setPos(x, y)
