@@ -22,15 +22,17 @@ class Playout(Heuristic):
         :return: 1 if the start_state's active player won the game, -1 for a
             loss, and 0 for a draw
         """
-        if start_state.is_ended():
-            value, policy = self.analyse_end_game(start_state)
-            return value
-        valid_moves, = np.nonzero(start_state.get_valid_moves())
-        if len(valid_moves) == 0:
-            raise ValueError('No valid moves found.\n' + start_state.display())
-        move = np.random.choice(valid_moves)
-        new_state = start_state.make_move(move)
-        new_state_value = self.simulate(new_state)
-        if new_state.get_active_player() == start_state.get_active_player():
-            return new_state_value
-        return -new_state_value
+        current_state = start_state
+        multiplier = 1
+        while True:
+            if current_state.is_ended():
+                value, policy = self.analyse_end_game(current_state)
+                return multiplier*value
+            valid_moves, = np.nonzero(current_state.get_valid_moves())
+            if len(valid_moves) == 0:
+                raise ValueError('No valid moves found.\n' + current_state.display())
+            move = np.random.choice(valid_moves)
+            new_state = current_state.make_move(move)
+            if new_state.get_active_player() != current_state.get_active_player():
+                multiplier *= -1
+            current_state = new_state
