@@ -2,6 +2,7 @@ import matplotlib.pyplot as plt
 from PySide2 import QtWidgets
 
 from numpy import arange, sin, pi
+from matplotlib.axes import Axes
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 from matplotlib.figure import Figure
 
@@ -11,11 +12,11 @@ plt.switch_backend('Qt5Agg')
 class PlotCanvas(FigureCanvas):
     def __init__(self, parent=None, width=5, height=4, dpi=100):
         fig = Figure(figsize=(width, height), dpi=dpi)
-        self.axes = fig.add_subplot(111)
+        self.axes: Axes = fig.add_subplot(111)
 
         self.compute_initial_figure()
 
-        FigureCanvas.__init__(self, fig)
+        super().__init__(fig)
         self.setParent(parent)
 
         FigureCanvas.setSizePolicy(self,
@@ -27,3 +28,4 @@ class PlotCanvas(FigureCanvas):
         t = arange(0.0, 3.0, 0.01)
         s = sin(2*pi*t)
         self.axes.plot(t, s)
+        self.axes.set_title("Coming Soon...")
